# tcl/openacsorg.tcl

ad_library {
  Provides helper routines for the OpenACS.org  site.

  @author Pat Colgan (pat@museatech.net)
  @creation-date September 6, 2001

}

ad_proc -public oacs_set_login_vars { } {
  uplevel {
    set user_id [ad_get_user_id]

    # One common problem with login is that people can hit the back button
    # after a user logs out and relogin by using the cached password in
    # the browser. We generate a unique hashed timestamp so that users
    # cannot use the back button.

    set time [ns_time]
    set token_id [sec_get_random_cached_token_id]
    set token [sec_get_token $token_id]
    set hash [ns_sha1 "$time$token_id$token"]

    set system_name [ad_system_name]

    set allow_persistent_login_p [ad_parameter -package_id [ad_acs_kernel_id] AllowPersistentLoginP security 1]
    if {[ad_parameter -package_id [ad_acs_kernel_id] PersistentLoginDefaultP security 1]} {
	set remember_password "checked"
    } else {
	set remember_password ""
    }

    set return_url [ns_conn url]
    set form_vars [export_form_vars return_url time token_id hash allow_persistent_login_p]

    set oacs_admin_p 0

    if { $user_id != 0 } {
	# The user is logged in.
	if {[db_0or1row user_name_select {
	    select first_names,
	    first_names || ' ' || last_name as user_name, email
	    from persons, parties
	    where person_id = :user_id
	    and person_id = party_id
	}]} {
	    set home_url [ad_pvt_home]
	    set home_url_name [ad_pvt_home_name]	
	}
	set requires_registration_p_clause ""

	set root_node_id [site_node_id "/"]
	set oacs_admin_p [ad_permission_p -user_id $user_id $root_node_id admin]
    }
  }
}



